CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
C                                                                 C
C     BIGD2 IS A PROGRAM DESIGNED TO CALCULATE THE                C
C     PARTITIONING BEHAVIOR OF TRACE ELEMENTS                     C
C     THIS VERSION OF BIGD CONSISTS OF TEMPERATURE DEPENDENT,     C
C     COMPOSITIONALLY INDEPENDENT, SINGLE COMPONENT               C
C     DISTRIBUTION COEFFICIENTS AND EQUILIBRIUM REACTIONS         C
C     FROM EXPERIMENTAL DATA.                                     C
C                                                                 C
C     THIS PROGRAM WAS WRITTEN BY ROGER NIELSEN,                  C
C     COLLEGE OF OCEANOGRAPHY,  OCEAN. ADMIN. 104,                C
C     OREGON STATE UNIV, CORVALLIS, OREGON 97731-5503             C
C     phone 503-737-3023.                                         C
C     e-mail  rnielsen@oce.orst.edu                               C
C     IBM VERSION 12/9/92                                         C
C                                                                 C
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
C     PROGRAM BIGD2
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      CHARACTER ELEM(60)*6, CRYST(30)*20
      DIMENSION GL(60), OPTION(20)
      DIMENSION G(60),X(14,60),WT(60), PIGTR(60), APTR(60)
      DIMENSION SLOPE(9,60),YCEPT(9,60),CPXTR(60),BIGD(20,60)
      DIMENSION OLTR(60),PLTR(60),SPTR(60),OPXTR(60),ILMTR(60)
      REAL ILMTR
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
C                                                     C
C      OPEN INPUT FILE CONTAINING REG. CONSTANTS      C
C                                                     C
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
      OPEN(UNIT=3,FILE='REGR.DAT',STATUS='old')
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
C       MINERAL NAMES - CRYST(I)            C
C      ELEMENT NAMES  -  ELEM(I)            C
C      MOLECULAR WEIGHTS - WT(I)            C
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
      DO 10 I=1,8
      READ(3,*) CRYST(I)
10    CONTINUE
      DO 20 I=1,11
      READ(3,*) ELEM(I),WT(I)
      GL(I)=0.0
20    CONTINUE
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
C                                                    C
C     INPUT TRACE ELEMENTS REGRESSION CONSTANTS      C
C                                                    C
C     INPUT SLOPES AND Y INTERCEPTS FOR TRACE        C
C     ELEMENT PARTITIONING                           C
C      SLOPE(J,I)    YCEPT(J,I)                      C
C                                                    C
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
      DO 60 I=12,42
      READ(3,*) ELEM(I)
      GL(I)=1.
      DO 50 J=1,8
      BIGD(J,I)=0.0
      READ(3,*) SLOPE(J,I),YCEPT(J,I)
      IF (YCEPT(J,I).EQ.0.0) YCEPT (J,I)=-20
50    CONTINUE
60    CONTINUE
      CLOSE(UNIT=3)
      PRINT *,'INPUT THE MAJOR ELEMENT COMPOSITION (WT%) OF THE MAGMA '
      DO 90 I=1,11
      PRINT *,ELEM(I),'  ?  '
      READ(*,*) GL(I)
90    CONTINUE
      PRINT *,'INPUT TEMPERATURE (C) '
      READ(*,*) T
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
C                                             C
C     OUTPUT STARTING CONDITIONS TO FILE      C
C                                             C
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
      OPEN(UNIT=3,FILE='BIGD.OUT',STATUS='UNKNOWN')
      WRITE(3,*) '  '
      WRITE(3,*) ' MAGMA COMPOSITION '
      WRITE(3,*) '  '
      WRITE(3,93) (ELEM(I),I=1,11)
93    FORMAT(2X,11A)
      WRITE(3,94) (GL(I),I=1,11)
94    FORMAT(11F6.2)
      WRITE(3,*) '  '
      WRITE(3,*) '  '
      WRITE(3,*) ' TEMPERATURE (C) = ', T
      WRITE(3,*) '  '
      T=T+273.
      SUM=0.
      DO 100 I=1,11
      GL(I)=GL(I)/WT(I)
      SUM=SUM+GL(I)
100   CONTINUE
      DO 110 I=1,11
      GL(I)=GL(I)/SUM
110   CONTINUE
      DO 115 I=1,42
      G(I)=GL(I)
115   CONTINUE
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
C                                           C
C         SELECTION OF PHASES               C
C                                           C
C                                           C
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
      PRINT *,' SELECT THE PHASES FOR WHICH YOU '
      PRINT *, 'WISH PARTITION COEFFICIENTS CALCULATED  '
      PRINT *, ' ENTER (1) AFTER EACH SELECTED PHASE '
      PRINT *,'     '
      DO 120 I=1,8
      PRINT *, CRYST(I), '      1 = YES      '
      READ (*,*) OPTION(I)
120   CONTINUE
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
C                                    C
C CALCULATION OF MELT COMPONENTS     C
C                                    C
C                                    C
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
      Y=G(1)+G(4)+G(6)
      S=G(2)+G(3)+G(5)+G(7)+G(8)+G(9)+G(10)+G(11)-G(1)-G(6)
      G(3)=(G(3)-G(1)-G(6))/S
      G(2)=G(2)/S
      G(6)=G(6)/S
      G(1)=G(1)/Y
      G(4)=G(4)/Y
      G(5)=G(5)/S
      G(6)=G(6)/Y
      G(7)=G(7)/S
      G(8)=G(8)/S
      G(9)=G(9)/S
      G(10)=G(10)/S
      G(11)=G(11)/S
      DO 140 I=12,42
      G(I)=G(I)/S
140   CONTINUE
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
C                                                    C
C         SUBSCRIPTS FOR ELEMENTS                    C
C	1  Na	12  Co	23  Cs	34  Er           C
C	2  Mg	13  Sc	24  Ba	35  Tm           C
C	3  Al	14  V  	25  La	36  Yb           C
C	4  Si	15  Cr	26  Ce	37  Lu           C
C	5  P  	16  Ni	27  Nd	38  Hf           C
C	6  K  	17  Zn	28  Sm	39  Ta           C
C	7  Ca	18  Rb	29  Eu+2	40  Pb           C
C	8  Ti	19  Sr	30  Eu+3	41  Th           C
C	9  Mn	20  Y	31  Gd	42  U            C
C	10  Fe+2	21  Zr	32  Dy	                 C
C	11  Fe+3	22  Nb	33  Ho	                 C
C                                                    C
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
1010   IF (OPTION(1).EQ.1) GO TO 150
1020   IF (OPTION(2).EQ.1) GO TO 200
1030   IF (OPTION(3).EQ.1) GO TO 300
1040   IF (OPTION(4).EQ.1) GO TO 400
1050   IF (OPTION(5).EQ.1) GO TO 500
1060   IF (OPTION(6).EQ.1) GO TO 600
1070   IF (OPTION(7).EQ.1) GO TO 700
1080   IF (OPTION(8).EQ.1) GO TO 800
      GO TO 830
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
C                                             C
C                 OLIVINE                     C
C                                             C
C                                             C
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
150   DO 160 I=12,42
      OLTR(I)=EXP(SLOPE(1,I)/T+YCEPT(1,I))*G(I)
160   CONTINUE
      OLTR(16)=EXP(SLOPE(1,16)/T+YCEPT(1,16))*G(16)*G(4)**0.5
      OLTR(15)=EXP(SLOPE(1,15)/T+YCEPT(1,15))*G(15)
      DO 165 I=12,42
      BIGD(1,I)=OLTR(I)
165   CONTINUE
      GO TO 1020
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
C                                            C
C         ORTHOPYROXENE                      C
C                                            C
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
200   PRINT *, ' INPUT ORTHOPYROXENE COMPOSITION '
      DO 210 I=1,11
      PRINT *,ELEM(I),'  ?  '
      READ(*,*) X(2,I)
210   CONTINUE
      WRITE(3,212) (ELEM(I),I=1,11)
212    FORMAT('     '11A)
      WRITE(3,215) (X(2,I),I=1,11)
215    FORMAT(' OPX ',11F6.2)
      SUM=0.
      DO 220 I=1,11
      X(2,I)=X(2,I)/WT(I)
      SUM=SUM+X(2,I)
220   CONTINUE
      DO 225 I=1,11
      X(2,I)=X(2,I)/SUM
225   CONTINUE
C
C     OPTION FOR CALCULATION OF TI IN PYROXENE
C
      PRINT *, ' IF YOU WANT OPX TI CONTENT TO BE CALCULATED '
      PRINT *, ' ENTER 1, OTHERWISE ENTER 0 '
      PRINT *, ' SELECT THIS OPTION ONLY FOR LOW PRESSURE '
      PRINT *, ' APPLICATIONS WHERE TEMPERATURE IS KNOWN '
      READ (*,*) OPTION(10)
      IF (OPTION(10).NE.1) GO TO 240
230   X(2,8)=(4934./T+105.6881*GL(3)**2-23.7*GL(3)+0.7897*
     :(2*GL(7)+GL(1)+GL(6))/GL(4)+0.3799*X(2,7)-2.4404)*GL(8)
240   DO 250 I=12,42
      OPXTR(I)=EXP(SLOPE(2,I)/T+YCEPT(2,I))*G(I)
250   CONTINUE
      OPXTR(15)=EXP(SLOPE(2,15)/T+YCEPT(2,15))*G(15)
      OPXTR(16)=EXP(SLOPE(2,16)/T+YCEPT(2,16))*G(16)
      BIGD(2,8)=X(2,8)/GL(8)
      PMN=0.
      BIGD(2,9)=PMN
      XMCA=X(2,2)*X(2,7)
      XCAMGL=G(7)*G(2)*G(4)
      GAF=G(3)*G(10)
C     OPTION FOR CALCULATION OF D(REE) BASED ON TI IN PYROXENE
      PRINT *, ' IF YOU WANT SC, Y AND REE D TO BE CALC ON THE '
      PRINT *, ' BASIS OF OPX TI CONTENT ENTER 1, OTHERWISE 0 '
      PRINT *, '  OPTION  1  IS BEST FOR HIGH PRESSURE D s '
      READ (*,*) OPTION(10)
      IF (OPTION(10).EQ.1) GO TO 252
      OPXTR(13)=YCEPT(2,13)*((XMCA*GAF*G(13))/(X(2,10)*XCAMGL))
      OPXTR(20)=YCEPT(2,20)*((XMCA*GAF*G(20))/(X(2,10)*XCAMGL))
      OPXTR(25)=YCEPT(2,25)*((XMCA*GAF*G(25))/(X(2,10)*XCAMGL))
      OPXTR(26)=YCEPT(2,26)*((XMCA*GAF*G(26))/(X(2,10)*XCAMGL))
      OPXTR(27)=YCEPT(2,27)*((XMCA*GAF*G(27))/(X(2,10)*XCAMGL))
      OPXTR(28)=YCEPT(2,28)*((XMCA*GAF*G(28))/(X(2,10)*XCAMGL))
      OPXTR(30)=YCEPT(2,30)*((XMCA*GAF*G(30))/(X(2,10)*XCAMGL))
      OPXTR(31)=YCEPT(2,31)*((XMCA*GAF*G(31))/(X(2,10)*XCAMGL))
      OPXTR(32)=YCEPT(2,32)*((XMCA*GAF*G(32))/(X(2,10)*XCAMGL))
      OPXTR(33)=YCEPT(2,33)*((XMCA*GAF*G(33))/(X(2,10)*XCAMGL))
      OPXTR(34)=YCEPT(2,34)*((XMCA*GAF*G(34))/(X(2,10)*XCAMGL))
      OPXTR(35)=YCEPT(2,35)*((XMCA*GAF*G(35))/(X(2,10)*XCAMGL))
      OPXTR(36)=YCEPT(2,36)*((XMCA*GAF*G(36))/(X(2,10)*XCAMGL))
      OPXTR(37)=YCEPT(2,37)*((XMCA*GAF*G(37))/(X(2,10)*XCAMGL))
      GO TO 254
252   OPXTR(13)=7.1*BIGD(2,8)+0.35
      OPXTR(20)=0.99*BIGD(2,8)
      OPXTR(25)=0.08*BIGD(2,8)
      OPXTR(26)=0.11*BIGD(2,8)
      OPXTR(27)=0.20*BIGD(2,8)
      OPXTR(28)=0.28*BIGD(2,8)
      OPXTR(30)=0.33*BIGD(2,8)
      OPXTR(31)=0.45*BIGD(2,8)
      OPXTR(32)=0.68*BIGD(2,8)
      OPXTR(33)=0.96*BIGD(2,8)
      OPXTR(34)=1.02*BIGD(2,8)
      OPXTR(35)=1.04*BIGD(2,8)
      OPXTR(36)=1.11*BIGD(2,8)
      OPXTR(37)=1.15*BIGD(2,8)
254   OPXTR(21)=0.255*BIGD(2,8)
      OPXTR(22)=0.0188*BIGD(2,8)
      OPXTR(38)=0.51*BIGD(2,8)
      OPXTR(39)=0.071*BIGD(2,8)
256   DO 260 I=12,42
      BIGD(2,I)=OPXTR(I)
260   CONTINUE
      GO TO 1030
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
C                                          C
C    PIGEONITE                             C
C                                          C
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
300   PRINT *, ' INPUT PIGEONITE COMPOSITION '
      DO 310 I=1,11
      PRINT *,ELEM(I),'  ?  '
      READ(*,*) X(3,I)
310   CONTINUE
      WRITE(3,315) (X(3,I),I=1,11)
315    FORMAT(' PIG ',11F6.2)
      SUM=0.
      DO 320 I=1,11
      X(3,I)=X(3,I)/WT(I)
      SUM=SUM+X(3,I)
320   CONTINUE
      DO 330 I=1,11
      X(3,I)=X(3,I)/SUM
330   CONTINUE
C     OPTION FOR CALCULATION OF TI IN PIGEONITE
      PRINT *, ' IF YOU WANT PIGEONITE TI CONTENT TO BE CALCULATED '
      PRINT *, ' ENTER 1, OTHERWISE ENTER 0 '
      PRINT *, ' SELECT THIS OPTION ONLY FOR LOW PRESSURE '
      PRINT *, ' APPLICATIONS WHERE TEMPERATURE IS KNOWN '
      READ (*,*) OPTION(10)
      IF (OPTION(10).NE.1) GO TO 350
      X(3,8)=(4934./T+105.6881*GL(3)**2-23.7*GL(3)+0.7897*
     :(2*GL(7)+GL(1)+GL(6))/GL(4)+0.3799*X(3,7)-2.4404)*GL(8)
350   DO 360 I=12,42
      PIGTR(I)=EXP(SLOPE(7,I)/T+YCEPT(7,I))*G(I)
360   CONTINUE
      PIGTR(15)=EXP(SLOPE(7,15)/T+YCEPT(7,15))*G(15)
      PIGTR(16)=EXP(SLOPE(7,16)/T+YCEPT(7,16))*G(16)
      BIGD(3,8)=X(3,8)/GL(8)
      XMCA=X(3,2)*X(3,7)
      XCAMGL=G(7)*G(2)*G(4)
      GAF=G(3)*G(10)
C     OPTION FOR CALCULATION OF D(REE) BASED ON TI IN PYROXENE
      PRINT *, ' IF YOU WANT SC, Y AND REE D TO BE CALC ON THE '
      PRINT *, ' BASIS OF PIG TI CONTENT ENTER 1, OTHERWISE 0 '
      PRINT *, ' THIS OPTION IS BEST FOR HIGH PRESSURE D s '
      READ (*,*) OPTION(10)
      IF (OPTION(10).EQ.1) GO TO 352
      PIGTR(13)=YCEPT(7,13)*((XMCA*GAF*G(13))/(X(3,10)*XCAMGL))
      PIGTR(20)=YCEPT(7,20)*((XMCA*GAF*G(20))/(X(3,10)*XCAMGL))
      PIGTR(25)=YCEPT(7,25)*((XMCA*GAF*G(25))/(X(3,10)*XCAMGL))
      PIGTR(26)=YCEPT(7,26)*((XMCA*GAF*G(26))/(X(3,10)*XCAMGL))
      PIGTR(27)=YCEPT(7,27)*((XMCA*GAF*G(27))/(X(3,10)*XCAMGL))
      PIGTR(28)=YCEPT(7,28)*((XMCA*GAF*G(28))/(X(3,10)*XCAMGL))
      PIGTR(30)=YCEPT(7,30)*((XMCA*GAF*G(30))/(X(3,10)*XCAMGL))
      PIGTR(31)=YCEPT(7,31)*((XMCA*GAF*G(31))/(X(3,10)*XCAMGL))
      PIGTR(32)=YCEPT(7,32)*((XMCA*GAF*G(32))/(X(3,10)*XCAMGL))
      PIGTR(33)=YCEPT(7,33)*((XMCA*GAF*G(33))/(X(3,10)*XCAMGL))
      PIGTR(34)=YCEPT(7,34)*((XMCA*GAF*G(34))/(X(3,10)*XCAMGL))
      PIGTR(35)=YCEPT(7,35)*((XMCA*GAF*G(35))/(X(3,10)*XCAMGL))
      PIGTR(36)=YCEPT(7,36)*((XMCA*GAF*G(36))/(X(3,10)*XCAMGL))
      PIGTR(37)=YCEPT(7,37)*((XMCA*GAF*G(37))/(X(3,10)*XCAMGL))
      GO TO 354
C
C       CALCULATION OF SC, Y AND REE ON THE BASIS OF DTI
C
352   PIGTR(13)=9.02 *BIGD(3,8)-0.6798*BIGD(3,8)**2-0.156
      PIGTR(20)=1.13*BIGD(3,8)
      PIGTR(25)=0.2112*BIGD(3,8)-0.0396*BIGD(3,8)**2-0.004
      PIGTR(26)=0.3816*BIGD(3,8)-0.0606*BIGD(3,8)**2-0.0083
      PIGTR(27)=0.7125*BIGD(3,8)-0.0727*BIGD(3,8)**2-0.0158
      PIGTR(28)=0.9552*BIGD(3,8)-0.0692*BIGD(3,8)**2-0.0219
      PIGTR(30)=1.0616*BIGD(3,8)-0.0726*BIGD(3,8)**2-0.022
      PIGTR(31)=1.1217*BIGD(3,8)-0.0521*BIGD(3,8)**2-0.022
      PIGTR(32)=1.1846*BIGD(3,8)-0.0191*BIGD(3,8)**2-0.0156
      PIGTR(33)=1.2161*BIGD(3,8)-0.0026*BIGD(3,8)**2-0.0126
      PIGTR(34)=1.1808*BIGD(3,8)+0.0002*BIGD(3,8)**2-0.0069
      PIGTR(35)=1.1632*BIGD(3,8)+0.0016*BIGD(3,8)**2-0.004
      PIGTR(36)=1.1104*BIGD(3,8)+0.0059*BIGD(3,8)**2+0.0046
      PIGTR(37)=1.0732*BIGD(3,8)+0.0104*BIGD(3,8)**2+0.0086
354   PIGTR(21)=0.5335*BIGD(3,8)-0.0058*BIGD(3,8)**2-0.023
      PIGTR(22)=0.0188*BIGD(3,8)
      PIGTR(38)=0.51*BIGD(3,8)
      PIGTR(39)=0.071*BIGD(3,8)
356   DO 370 I=12,42
      BIGD(3,I)=PIGTR(I)
370   CONTINUE
      GO TO 1040
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
C                                      C
C        AUGITE                        C
C                                      C
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
400   PRINT *, ' INPUT AUGITE COMPOSITION '
      DO 410 I=1,11
      PRINT *,ELEM(I),'  ?  '
      READ(*,*) X(4,I)
410   CONTINUE
      WRITE(3,415) (X(4,I),I=1,11)
415    FORMAT(' CPX ',11F6.2)
      SUM=0.
      DO 420 I=1,11
      X(4,I)=X(4,I)/WT(I)
      SUM=SUM+X(4,I)
420   CONTINUE
      DO 430 I=1,11
      X(4,I)=X(4,I)/SUM
430   CONTINUE
C     OPTION TO CALCULATE TI IN AUGITE 
      PRINT *, ' IF YOU WANT AUGITE TI CONTENT TO BE CALCULATED '
      PRINT *, ' ENTER 1, OTHERWISE ENTER 0 '
      PRINT *, ' SELECT THIS OPTION ONLY FOR LOW PRESSURE '
      PRINT *, ' APPLICATIONS WHERE TEMPERATURE IS KNOWN '
      READ (*,*) OPTION(10)
      IF (OPTION (10).NE.1) GO TO 450
      X(4,8)=(4934./T+105.6881*GL(3)**2-23.7*GL(3)+0.7897*
     :(2*GL(7)+GL(1)+GL(6))/GL(4)+0.3799*X(4,7)-2.4404)*GL(8)
450   DO 460 I=12,42
      CPXTR(I)=EXP(SLOPE(3,I)/T+YCEPT(3,I))*G(I)
460   CONTINUE
      BIGD(4,8)=X(4,8)/GL(8)
      DENOM=(G(7)*G(2)*G(4)*X(4,10))
      XMCA=(X(4,2)*X(4,7)*G(3)*G(10))/DENOM
      CPXTR(15)=EXP(SLOPE(3,15)/T+YCEPT(3,15))*G(15)
      CPXTR(16)=EXP(SLOPE(3,16)/T+YCEPT(3,16))*G(16)
C     OPTION FOR CALCULATION OF D(REE) BASED ON TI IN PYROXENE
      PRINT *, ' IF YOU WANT SC, Y AND REE D TO BE CALC ON THE '
      PRINT *, ' BASIS OF AUGITE TI CONTENT, ENTER 1, OTHERWISE 0 '
      PRINT *, ' THIS OPTION IS BEST FOR HIGH PRESSURE D s '
      READ (*,*) OPTION(10)
      IF (OPTION(10).EQ.1) GO TO 472
      CPXTR(13)=EXP(SLOPE(3,13)/T+YCEPT(3,13))*XMCA*G(13)
      CPXTR(20)=EXP(SLOPE(3,20)/T+YCEPT(3,20))*XMCA*G(20)
      CPXTR(25)=EXP(SLOPE(3,25)/T+YCEPT(3,25))*XMCA*G(25)
      CPXTR(26)=EXP(SLOPE(3,26)/T+YCEPT(3,26))*XMCA*G(26)
      CPXTR(27)=EXP(SLOPE(3,27)/T+YCEPT(3,27))*XMCA*G(27)
      CPXTR(28)=EXP(SLOPE(3,28)/T+YCEPT(3,28))*XMCA*G(28)
      CPXTR(30)=EXP(SLOPE(3,30)/T+YCEPT(3,30))*XMCA*G(30)
      CPXTR(31)=EXP(SLOPE(3,31)/T+YCEPT(3,31))*XMCA*G(31)
      CPXTR(32)=EXP(SLOPE(3,32)/T+YCEPT(3,32))*XMCA*G(32)
      CPXTR(33)=EXP(SLOPE(3,33)/T+YCEPT(3,33))*XMCA*G(33)
      CPXTR(34)=EXP(SLOPE(3,34)/T+YCEPT(3,34))*XMCA*G(34)
      CPXTR(35)=EXP(SLOPE(3,35)/T+YCEPT(3,35))*XMCA*G(35)
      CPXTR(36)=EXP(SLOPE(3,36)/T+YCEPT(3,36))*XMCA*G(36)
      CPXTR(37)=EXP(SLOPE(3,37)/T+YCEPT(3,37))*XMCA*G(37)
      GO TO 474
472   CPXTR(13)=9.02 *BIGD(4,8)-0.6798*BIGD(4,8)**2-0.156
      CPXTR(20)=1.13*BIGD(4,8)
      CPXTR(25)=0.2112*BIGD(4,8)-0.0396*BIGD(4,8)**2-0.004
      CPXTR(26)=0.3816*BIGD(4,8)-0.0606*BIGD(4,8)**2-0.0083
      CPXTR(27)=0.7125*BIGD(4,8)-0.0727*BIGD(4,8)**2-0.0158
      CPXTR(28)=0.9552*BIGD(4,8)-0.0692*BIGD(4,8)**2-0.0219
      CPXTR(30)=1.0616*BIGD(4,8)-0.0726*BIGD(4,8)**2-0.022
      CPXTR(31)=1.1217*BIGD(4,8)-0.0521*BIGD(4,8)**2-0.022
      CPXTR(32)=1.1846*BIGD(4,8)-0.0191*BIGD(4,8)**2-0.0156
      CPXTR(33)=1.2161*BIGD(4,8)-0.0026*BIGD(4,8)**2-0.0126
      CPXTR(34)=1.1808*BIGD(4,8)+0.0002*BIGD(4,8)**2-0.0069
      CPXTR(35)=1.1632*BIGD(4,8)+0.0016*BIGD(4,8)**2-0.004
      CPXTR(36)=1.1104*BIGD(4,8)+0.0059*BIGD(4,8)**2+0.0046
      CPXTR(37)=1.0732*BIGD(4,8)+0.0104*BIGD(4,8)**2+0.0086
C
C     PARTITIONING BEHAVIOR OF ZR, NB, HF AND TA CALC. ON
C     THE BASIS OF DTI
C
474   CPXTR(21)=0.5335*BIGD(4,8)-0.0058*BIGD(4,8)**2-0.023
      CPXTR(22)=(SLOPE(3,22)*BIGD(4,8)+YCEPT(3,22))
      CPXTR(38)=(SLOPE(3,38)*BIGD(4,8)+YCEPT(3,38))
      CPXTR(39)=(SLOPE(3,39)*BIGD(4,8)+YCEPT(3,39))
476   DO 480 I=12,42
      BIGD(4,I)=CPXTR(I)
480   CONTINUE
      GO TO 1050
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
C                                            C
C          PLAGIOCLASE                       C
C                                            C
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
500   DO 510 I=12,42
      PLTR(I)=EXP(SLOPE(4,I)/T+YCEPT(4,I))*G(I)
510   CONTINUE
C      BA AND SR REGRESSIONS
      PLTR(19)=EXP(SLOPE(4,19)/T+YCEPT(4,19))*G(19)*(G(3)*G(4))**2
      PLTR(24)=EXP(SLOPE(4,24)/T+YCEPT(4,24))*G(24)*(G(3)*G(4))**2
      DO 550 I=12,42
      BIGD(5,I)=PLTR(I)
550   CONTINUE
      GO TO 1060
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
C                                     C
C                                     C
C             SPINEL                  C
C                                     C
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
600   PRINT *, ' INPUT SPINEL OR MAGNETITE COMPOSITION '
       DO 610 I=1,11
       PRINT *,ELEM(I),'  ?  '
       READ(*,*) X(6,I)
610     CONTINUE
      WRITE(3,614) (X(6,I),I=1,11)
614    FORMAT(' SPN ',11F6.2)
      SUM=0.
      DO 615 I=1,11
      X(6,I)=X(6,I)/WT(I)
      SUM=SUM+X(6,I)
615   CONTINUE
      DO 620 I=1,11
      X(6,I)=X(6,I)/SUM
620   CONTINUE
      BIGD(6,8)=X(6,8)/GL(8)
      DO 630 I=12,42
      SPTR(I)=EXP(SLOPE(5,I)/T+YCEPT(5,I))*G(I)
630   CONTINUE
      SPTR(15)=EXP(SLOPE(5,15)/T+YCEPT(5,15))*0.2*G(15)
      SPTR(16)=EXP(SLOPE(5,16)/T+YCEPT(5,16))*G(16)
      SPTR(20)=YCEPT(5,20)
      DO 635 I=25,37
      SPTR(I)=YCEPT(5,I)
635   CONTINUE
640   SPTR(21)=0.0267*BIGD(6,8)+0.004*BIGD(6,8)**2-0.0209
      SPTR(22)=0.0332*BIGD(6,8)+0.0037*BIGD(6,8)**2-0.0204
      SPTR(38)=0.0381*BIGD(6,8)+0.0046*BIGD(6,8)**2-0.034
      SPTR(39)=0.0491*BIGD(6,8)+0.0045*BIGD(6,8)**2-0.035
650   DO 670 I=12,42
      BIGD(6,I)=SPTR(I)
670   CONTINUE
      GO TO 1070
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
C                                            C
C    ILMENITE                                C
C                                            C
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
700   DO 710 I=12,42
      ILMTR(I)=EXP(SLOPE(6,I)/T+YCEPT(6,I))*G(I)
710   CONTINUE
      DO 720 I=25,37
      ILMTR(I)=YCEPT(6,I)
720   CONTINUE
      ILMTR(15)=11.*G(15)
      ILMTR(20)=YCEPT(6,20)
      DO 740 I=12,42
      BIGD(7,I)=ILMTR(I)
740   CONTINUE
      GO TO 1080
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
C                                           C
C       APATITE                             C
C                                           C
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
800   DO 810 I=12,42
      APTR(I)=EXP(SLOPE(8,I)/T+YCEPT(8,I))*G(I)
810   CONTINUE
      DO 820 I=12,42
      BIGD(8,I)=APTR(I)
820   CONTINUE
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
C                                        C
C                                        C
C      OUTPUT TO FILE BIGD.OUT           C
C                                        C
C                                        C
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
830   WRITE(3,850)
850   FORMAT('         OLIVINE    OPX      PIG    AUGITE  
     :  PLAG    SPINEL    ILMEN    APAT ')
      DO 980 I=12,42
      WRITE(3,900) ELEM(I),(BIGD(J,I),J=1,8)
900   FORMAT(A,8(F9.4))
980   CONTINUE
      STOP
      END